# Convert Videos
[![Run Status](https://api.shippable.com/projects/583586b74dac720f008ca29c/badge?branch=master)](https://app.shippable.com/projects/583586b74dac720f008ca29c)
[![Coverage Badge](https://api.shippable.com/projects/583586b74dac720f008ca29c/coverageBadge?branch=master)](https://app.shippable.com/projects/583586b74dac720f008ca29c)

This application will take a folder full of videos and make sure they are converted to the specified format.
